@@ -3,16 +3,16 @@
 """Provide GCS functions to control a PI device."""
 # Trailing newlines pylint: disable=C0305
 
-from logging import warning
+from ...PILogger import PIDebug, PIWarning
 # Wildcard import pipython.gcscommands_helpers pylint: disable=W0401
 # Unused import platform from wildcard import pylint: disable=W0614
 from ..common.gcscommands_helpers import *
 from ..common.gcsbasecommands import GCSBaseCommands
 from .. import gcserror
 from ..gcserror import GCSError
+from ...version import __version__
 
-
-__signature__ = 0xf98df39c543ba193811e90bedad17c7
+__signature__ = 0xc9f8215e5e3e9a0d6572f25ee0766f20
 
 GCSFUNCTIONS = {
     'E-816': [
@@ -58,17 +58,12 @@ class GCS2Commands(GCSBaseCommands):
         """Wrapper for PI GCS DLL.
         @type msgs : pipython.pidevice.gcsmessages.GCSMessages
         """
-        debug('create an instance of GCS2Commands(msgs=%s)', str(msgs))
-        super(GCS2Commands, self).__init__(msgs)
+        PIDebug('create an instance of GCS2Commands(msgs=%s)', str(msgs))
+        super().__init__(msgs)
 
     def __str__(self):
         return 'GCS2Commands(msgs=%s)' % str(self._msgs)
 
-    #    @property
-    #    def connectionid(self):
-    #        """Get ID of current connection as integer."""
-    #        return super(GCS2Commands, self).connectionid
-
     @property
     def devname(self):
         """Return device name from its IDN string."""
@@ -80,21 +75,22 @@ class GCS2Commands(GCSBaseCommands):
                 self._name = 'E-710'
             else:
                 self._name = idn.split(',')[1].strip()
-            debug('GCS2Commands.devname: set to %r', self._name)
+            PIDebug('GCS2Commands.devname: set to %r', self._name)
         return self._name
 
     @devname.setter
     def devname(self, devname):
         """Set device name as string, only for testing."""
         super(GCS2Commands, self.__class__).devname.fset(self, devname)
-        warning('controller name is coerced to %r', self._name)
+        PIWarning('controller name is coerced to %r', self._name)
 
     @devname.deleter
     def devname(self):
         """Reset device name."""
         self._name = None
         super(GCS2Commands, self.__class__).devname.fdel(self)
-        debug('GCS2Commands.devname: reset')
+#        super().devname.fdel(self)
+        PIDebug('GCS2Commands.devname: reset')
 
     @property
     def funcs(self):
@@ -109,8 +105,9 @@ class GCS2Commands(GCSBaseCommands):
     @funcs.deleter
     def funcs(self):
         """Reset list of supported GCS functions."""
-        debug('GCS2Commands.funcs: reset')
+        PIDebug('GCS2Commands.funcs: reset')
         super(GCS2Commands, self.__class__).funcs.fdel(self)
+#        super().funcs.fdel(self)
 
     def paramconv(self, paramdict):
         """Convert values in 'paramdict' to according type in qHPA answer.
@@ -126,6 +123,12 @@ class GCS2Commands(GCSBaseCommands):
 
         return paramdict
 
+    def update_paramconv_if_necessary(self):
+        """
+        updates the the parameter convert dict if the current user level his higher the the user level at the last
+        update of the parameter convert dict.
+        """
+
     def initparamconv(self):
         """Initialize paramconv .
         """
@@ -144,7 +147,6 @@ class GCS2Commands(GCSBaseCommands):
                 else:
                     raise KeyError('unknown parameter type %r' % convtype)
 
-    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
     def StopAll(self, noraise=False):
         """Stop all axes abruptly by sending "#24".
         Stop all motion caused by move commands (e.g. MOV, MVR, GOH, STE, SVA, SVR), referencing
@@ -154,46 +156,34 @@ class GCS2Commands(GCSBaseCommands):
         May raise GCSError(E10_PI_CNTR_STOP).
         @param noraise : If True a GCS error 10 (controller was stopped by command) will not be raised.
         """
-        debug('GCS2Commands.StopAll(noraise=%s)', noraise)
+        PIDebug('GCS2Commands.StopAll(noraise=%s)', noraise)
         try:
             self._msgs.send(chr(24))
         except GCSError as exc:
             if noraise and exc == gcserror.E10_PI_CNTR_STOP:
-                debug('GCSError 10 is catched and will not raise')
+                PIDebug('GCSError 10 is catched and will not raise')
             else:
                 raise
 
-    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
-    def HasStopAll(self):
-        """Return True if StopAll() is available."""
-        return self._has('StopAll')
-
-    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
     def IsMoving(self, axes=None):
         """Check if 'axes' are moving.
         If an axis is moving the corresponding element will be True, otherwise False.
         @param axes : String convertible or list of them or None.
         @return : Ordered dictionary of {axis: value}, values are bool.
         """
-        debug('GCS2Commands.IsMoving(axes=%r)', axes)
+        PIDebug('GCS2Commands.IsMoving(axes=%r)', axes)
         checksize((), axes)
         answer = self._msgs.read(chr(5))
         value = int(answer.strip(), base=16)
         answerdict = getbitcodeditems(value, self.allaxes, axes)
-        debug('GCS2Commands.IsMoving = %r', answerdict)
+        PIDebug('GCS2Commands.IsMoving = %r', answerdict)
         return answerdict
 
-    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
-    def HasIsMoving(self):
-        """Return True if IsMoving() is available."""
-        return self._has('IsMoving')
-
-    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
     def IsControllerReady(self):
         """Test if controller is ready, corresponds to GCS command "#7". No error check.
         @return : True if controller is ready.
         """
-        debug('GCS2Commands.IsControllerReady()')
+        PIDebug('GCS2Commands.IsControllerReady()')
         errcheck = self._msgs.errcheck
         self._msgs.errcheck = False
         answer = self._msgs.read(chr(7))
@@ -206,15 +196,23 @@ class GCS2Commands(GCSBaseCommands):
             else:
                 raise TypeError
         except TypeError:
-            raise ValueError('unexpected response %r for IsControllerReady()' % answer)
-        debug('GCS2Commands.IsControllerReady = %r', answer)
+            raise ValueError('unexpected response %r for IsControllerReady()' % answer) from TypeError
+        PIDebug('GCS2Commands.IsControllerReady = %r', answer)
         return answer
 
-    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
-    def HasIsControllerReady(self):
-        """Return True if IsControllerReady() is available."""
-        return self._has('IsControllerReady')
+    def qVER(self):
+        """Get version information about firmware and modules.
+        @return : Version information as string with trailing linefeeds.
+        """
+        PIDebug('GCSBaseCommands.qVER()')
+        answer = self._msgs.read('VER?')
+        answer = answer[:-1] + ' \nPIPython: %s\n' % __version__
+
+        PIDebug('GCSBaseCommands.qVER = %r', answer)
+        return answer
 
     # GCS FUNCTIONS ### DO NOT MODIFY THIS LINE !!! ###############################################
 
     # CODEGEN BEGIN ### DO NOT MODIFY THIS LINE !!! ###############################################
+
+
