@@ -2,12 +2,13 @@
 # -*- coding: utf-8 -*-
 """Provide access to the serial port. Requires the "pyserial" package (pip install pyserial)."""
 
-from logging import debug
 import serial
 
-from ..interfaces.pigateway import PIGateway
+from ...PILogger import PIDebug
+from ..interfaces.pigateway import PIGateway, PI_CONTROLLER_CODEPAGE
 
-__signature__ = 0xabc96582bdfb6a0f4cd78a6722a1a23d
+
+__signature__ = 0xdca3b828dfe0cfd9fad2ec504c040e6a
 
 
 class PISerial(PIGateway):
@@ -19,7 +20,7 @@ class PISerial(PIGateway):
         @param baudrate : Baud rate as integer.
         @param autoconnect : automaticly connect to controller if True (default)
         """
-        debug('create an instance of PISerial(port=%s, baudrate=%s)', port, baudrate)
+        PIDebug('create an instance of PISerial(port=%s, baudrate=%s)', port, baudrate)
         self._timeout = 7000  # milliseconds
         self._connected = False
         self._baudrate = baudrate
@@ -61,8 +62,8 @@ class PISerial(PIGateway):
         """Send 'msg' to the serial port.
         @param msg : String to send.
         """
-        debug('PISerial.send: %r', msg)
-        self._ser.write(msg.encode('cp1252'))
+        PIDebug('PISerial.send: %r', msg)
+        self._ser.write(msg.encode(PI_CONTROLLER_CODEPAGE))
 
     def read(self):
         """Return the answer to a GCS query command.
@@ -70,12 +71,12 @@ class PISerial(PIGateway):
         """
         received = self._ser.read_all()
         if len(received) != 0:
-            debug('PISerial.read: %r', received)
-        return received
+            PIDebug('PISerial.read: %r', received)
+        return received.decode(encoding=PI_CONTROLLER_CODEPAGE, errors='ignore')
 
     def flush(self):
         """Flush input buffer."""
-        debug('PISerial.flush()')
+        PIDebug('PISerial.flush()')
         self._ser.read_all()
 
     def unload(self):
@@ -85,9 +86,10 @@ class PISerial(PIGateway):
         """Close serial port if connected."""
         if not self.connected:
             return
-        debug('PISerial.close: close connection to port %r', self._ser.port)
+        PIDebug('PISerial.close: close connection to port %r', self._ser.port)
         self._connected = False
         self._ser.close()
+        self.call_connection_status_changed_callback(self)
 
     # Method name "ConnectRS232" doesn't conform to snake_case naming style pylint: disable=C0103
     def ConnectRS232(self, port, baudrate):
@@ -98,3 +100,4 @@ class PISerial(PIGateway):
         self._ser = serial.Serial(port=port, baudrate=baudrate, timeout=self._timeout / 1000.)
         self._connected = True
         self.flush()
+        self.call_connection_status_changed_callback(self)
