@@ -2,7 +2,6 @@
 # -*- coding: utf-8 -*-
 """Provide a USB Interface over LibUSB."""
 
-from logging import debug, error
 import re
 
 # Unable to import pylint: disable=E0401
@@ -10,10 +9,11 @@ import usb.core
 import usb.util
 import usb.backend.libusb1
 
-from ..interfaces.pigateway import PIGateway
+from ...PILogger import PIDebug, PIError
+from ..interfaces.pigateway import PIGateway, PI_CONTROLLER_CODEPAGE
 from .. import GCSError, gcserror
 
-__signature__ = 0xb30a1b4544aa5c422f1a463c9f09495e
+__signature__ = 0xa0171dbde73a8723f113f43ac4667f5a
 
 
 class PIUSB(PIGateway):
@@ -21,7 +21,7 @@ class PIUSB(PIGateway):
 
     def __init__(self):
         """Provide a PIUSB."""
-        debug('create an instance of PIUSB()')
+        PIDebug('create an instance of PIUSB()')
         self._timeout = 7000  # milliseconds
         self._ifnum = None
         self._reattach = False
@@ -52,9 +52,9 @@ class PIUSB(PIGateway):
         @return : Answer as string.
         """
         received = self._ep_in.read(self._ep_in.wMaxPacketSize, timeout=self.timeout).tostring()
-        debug('PIUSB.read: %r', received)
+        PIDebug('PIUSB.read: %r', received)
         received = received.rstrip(b'\0')  # some controllers return their answer in a size of modulus 2
-        return received
+        return received.decode(encoding=PI_CONTROLLER_CODEPAGE, errors='ignore')
 
     @property
     def connected(self):
@@ -74,7 +74,7 @@ class PIUSB(PIGateway):
         @param vid : USB Vendor ID as integer.
         @return : List of dicts with device info, all values as strings.
         """
-        debug('PIUSB.enumerate(vid=%#x)', vid)
+        PIDebug('PIUSB.enumerate(vid=%#x)', vid)
         devicesinfo = []
         if not pid:
             devices = usb.core.find(find_all=True, idVendor=vid)
@@ -88,7 +88,7 @@ class PIUSB(PIGateway):
             deviceinfo.update({'SerialNumber': getdevinfo(dev, dev.iSerialNumber)})
             deviceinfo.update({'VID': hex(dev.idVendor)})
             deviceinfo.update({'PID': hex(dev.idProduct)})
-            debug('PIUSB.enumerate: %s', deviceinfo)
+            PIDebug('PIUSB.enumerate: %s', deviceinfo)
             devicesinfo.append(deviceinfo)
             usb.util.dispose_resources(dev)
         return devicesinfo
@@ -99,7 +99,7 @@ class PIUSB(PIGateway):
         @param pid : USB Product ID of the device.
         @param vid : USB Vendor ID of the device.
         """
-        debug('PIUSB.connect(serialnumber=%s, pid=%#x, vid=%#x)', serialnumber, pid, vid)
+        PIDebug('PIUSB.connect(serialnumber=%s, pid=%#x, vid=%#x)', serialnumber, pid, vid)
         self._dev = self._find_device(serialnumber, pid, vid)
         self._dev.set_configuration()
         cfg = self._dev.get_active_configuration()
@@ -115,10 +115,12 @@ class PIUSB(PIGateway):
             self._dev.detach_kernel_driver(self._ifnum)
         usb.util.claim_interface(self._dev, self._ifnum)
         self.flush()
+        self.call_connection_status_changed_callback(self)
+
 
     def flush(self):
         """Flush input buffer."""
-        debug('PIUSB.flush()')
+        PIDebug('PIUSB.flush()')
         while True:
             try:
                 self._ep_in.read(self._ep_in.wMaxPacketSize, timeout=100)
@@ -131,8 +133,8 @@ class PIUSB(PIGateway):
         """
         if len(msg) % 2:  # some controllers need a string of size of modulus 2
             msg += '\0'
-        debug('PIUSB.send: %r', msg)
-        if self._ep_out.write(msg) != len(msg):
+        PIDebug('PIUSB.send: %r', msg)
+        if self._ep_out.write(msg.encode(PI_CONTROLLER_CODEPAGE)) != len(msg):
             raise GCSError(gcserror.E_2_SEND_ERROR)
 
     def unload(self):
@@ -142,7 +144,7 @@ class PIUSB(PIGateway):
         """Close connection if connected."""
         if not self.connected:
             return
-        debug('PIUSB.close: close connection ID %d', self.connectionid)
+        PIDebug('PIUSB.close: close connection ID %d', self.connectionid)
         usb.util.release_interface(self._dev, self._ifnum)
         if self._reattach:
             self._dev.attach_kernel_driver(self._ifnum)
@@ -152,6 +154,7 @@ class PIUSB(PIGateway):
         self._ep_out = None
         self._ep_in = None
         self._dev = None
+        self.call_connection_status_changed_callback(self)
 
     @staticmethod
     def _find_device(serialnumber, pid, vid):
@@ -161,17 +164,27 @@ class PIUSB(PIGateway):
         @param vid : Device vendor ID as integer.
         @return : USB device instance.
         """
-        debug('PIUSB._find_device(serialnumber=%s, pid=%#x, vid=%#x)', serialnumber, pid, vid)
+        PIDebug('PIUSB._find_device(serialnumber=%s, pid=%#x, vid=%#x)', serialnumber, pid, vid)
         devices = usb.core.find(find_all=True, idVendor=vid, idProduct=pid)
         if not devices:
             raise GCSError(gcserror.E_6_CONNECTION_FAILED)
         for dev in devices:
-            debug('PIUSB._find_device:\n%s', dev)
+            PIDebug('PIUSB._find_device:\n%s', dev)
             if getdevinfo(dev, dev.iSerialNumber) == serialnumber:
                 return dev
             usb.util.dispose_resources(dev)
         raise GCSError(gcserror.E_6_CONNECTION_FAILED)
 
+    # Method name doesn't conform to snake_case naming style pylint: disable=C0103
+    def ConnectUSB(self, serialnum, pid, vid=0x1a72):
+        """Open an USB connection to a device.
+        @param serialnum: Serial number of device or one of the
+        identification strings listed by EnumerateUSB().
+        @param pid : USB Product ID of the device (only for native usb).
+        @param vid : USB Vendor ID of the device  (only for native usb).
+        """
+        self.connect(serialnum, pid, vid)
+
 
 def getdevinfo(dev, stringid):
     """Return device info as string.
@@ -182,5 +195,5 @@ def getdevinfo(dev, stringid):
     try:
         return re.sub('[^a-zA-Z0-9-_*. ]', '', usb.util.get_string(dev, stringid))
     except ValueError:
-        error('probably you do not have permission to access USB descriptors')
+        PIError('probably you do not have permission to access USB descriptors')
         raise
