@@ -1,9 +1,8 @@
-__signature__ = 0xc46658a4dcc6d7c296503291ac846c24
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 """This example shows how to connect PIPython via serial port."""
 
-# (c)2016-2021 Physik Instrumente (PI) GmbH & Co. KG
+# (c)2016 Physik Instrumente (PI) GmbH & Co. KG
 # Software products that are provided by PI are subject to the
 # General Software License Agreement of Physik Instrumente (PI) GmbH & Co. KG
 # and may incorporate and/or make use of third-party software components.
@@ -15,13 +14,13 @@ __signature__ = 0xc46658a4dcc6d7c296503291ac846c24
 # http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf
 
 
-from __future__ import print_function
 import sys
 
 from pipython.pidevice.gcscommands import GCSCommands
 from pipython.pidevice.gcsmessages import GCSMessages
 from pipython.pidevice.interfaces.piserial import PISerial
 
+__signature__ = 0xe5184c9a60a0c98663347f677824582a
 
 
 def main():
@@ -38,6 +37,6 @@ def main():
 
 
 if __name__ == '__main__':
-    # import logging
-    # logging.basicConfig(level=logging.DEBUG)
+    # from pipython import PIlogger, DEBUG, INFO, WARNING, ERROR, CRITICAL
+    # PIlogger.setLevel(DEBUG)
     main()
