@@ -1,9 +1,8 @@
-__signature__ = 0xe8995ecfdc4b06fb86286300058193aa
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 """This example shows how to connect PIPython via socket."""
 
-# (c)2016-2021 Physik Instrumente (PI) GmbH & Co. KG
+# (c)2016 Physik Instrumente (PI) GmbH & Co. KG
 # Software products that are provided by PI are subject to the
 # General Software License Agreement of Physik Instrumente (PI) GmbH & Co. KG
 # and may incorporate and/or make use of third-party software components.
@@ -15,12 +14,12 @@ __signature__ = 0xe8995ecfdc4b06fb86286300058193aa
 # http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf
 
 
-from __future__ import print_function
-
 from pipython.pidevice.gcscommands import GCSCommands
 from pipython.pidevice.gcsmessages import GCSMessages
 from pipython.pidevice.interfaces.pisocket import PISocket
 
+__signature__ = 0xe3d86f8254f995996b5d31420e3b6818
+
 IPADDR = '192.168.90.166'
 
 
@@ -34,6 +33,6 @@ def main():
 
 
 if __name__ == '__main__':
-    # import logging
-    # logging.basicConfig(level=logging.DEBUG)
+    # from pipython import PIlogger, DEBUG, INFO, WARNING, ERROR, CRITICAL
+    # PIlogger.setLevel(DEBUG)
     main()
