@@ -1,9 +1,8 @@
-__signature__ = 0x3de195de202ecebe89850d7c4e34e893
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-"""This example shows how to use the data recorder and plot and save the data."""
+"""This example shows how to use the data recorder and how to plot and save the data."""
 
-# (c)2016-2021 Physik Instrumente (PI) GmbH & Co. KG
+# (c)2016 Physik Instrumente (PI) GmbH & Co. KG
 # Software products that are provided by PI are subject to the
 # General Software License Agreement of Physik Instrumente (PI) GmbH & Co. KG
 # and may incorporate and/or make use of third-party software components.
@@ -14,8 +13,7 @@ __signature__ = 0x3de195de202ecebe89850d7c4e34e893
 # Third Party Software Note:
 # http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf
 
-
-from __future__ import print_function
+"""This sample requires the python package matplotlib to work"""
 
 try:
     from matplotlib import pyplot
@@ -24,6 +22,8 @@ except ImportError:
 
 from pipython import GCSDevice, datarectools, pitools
 
+__signature__ = 0x35ba4672d5abc717f68a7c8ecfb9bafa
+
 CONTROLLERNAME = 'C-884'
 STAGES = ['M-111.1DG', ]  # connect stages to axes
 REFMODES = ['FNL', ]  # reference the connected stages
@@ -81,6 +81,6 @@ def processdata(drec):
 
 
 if __name__ == '__main__':
-    # import logging
-    # logging.basicConfig(level=logging.DEBUG)
+    # from pipython import PIlogger, DEBUG, INFO, WARNING, ERROR, CRITICAL
+    # PIlogger.setLevel(DEBUG)
     main()
