@@ -1,9 +1,8 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-__signature__ = 0x6ffbd08bff093fbcb209716cd8a49e3a
 """This example connects to a PIPython device."""
 
-# (c)2016-2021 Physik Instrumente (PI) GmbH & Co. KG
+# (c)2016 Physik Instrumente (PI) GmbH & Co. KG
 # Software products that are provided by PI are subject to the
 # General Software License Agreement of Physik Instrumente (PI) GmbH & Co. KG
 # and may incorporate and/or make use of third-party software components.
@@ -15,10 +14,9 @@ __signature__ = 0x6ffbd08bff093fbcb209716cd8a49e3a
 # http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf
 
 
-from __future__ import print_function
-
 from pipython import GCSDevice
 
+__signature__ = 0xdd4ba763b303c0f7562b08fd884ca11e
 
 def main():
     """Connect to a PIPython device."""
@@ -28,8 +26,8 @@ def main():
     with GCSDevice() as pidevice:
         # Choose the interface which is appropriate to your cabling.
 
-        #pidevice.ConnectTCPIP(ipaddress='192.168.178.42')
-        pidevice.ConnectUSB(serialnum='104237344')
+        pidevice.ConnectTCPIP(ipaddress='192.168.178.42')
+        # pidevice.ConnectUSB(serialnum='104237344')
         # pidevice.ConnectRS232(comport=1, baudrate=115200)
 
         # Each PI controller supports the qIDN() command which returns an
@@ -52,7 +50,7 @@ if __name__ == '__main__':
     # two hashtags. Then debug messages are shown. This can be helpful if
     # there are any issues.
 
-    # import logging
-    # logging.basicConfig(level=logging.DEBUG)
+    # from pipython import PIlogger, DEBUG, INFO, WARNING, ERROR, CRITICAL
+    # PIlogger.setLevel(DEBUG)
 
     main()
