@@ -1,9 +1,8 @@
-__signature__ = 0x59b6d589fbcaf327eedc4f70f9f539cc
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 """This example helps you to get used to PIPython."""
 
-# (c)2016-2021 Physik Instrumente (PI) GmbH & Co. KG
+# (c)2016 Physik Instrumente (PI) GmbH & Co. KG
 # Software products that are provided by PI are subject to the
 # General Software License Agreement of Physik Instrumente (PI) GmbH & Co. KG
 # and may incorporate and/or make use of third-party software components.
@@ -15,10 +14,10 @@ __signature__ = 0x59b6d589fbcaf327eedc4f70f9f539cc
 # http://www.physikinstrumente.com/download/TPSWNote_PhysikInstrumenteGmbH_Co_KG.pdf
 
 
-from __future__ import print_function
-
 from pipython import GCSDevice, pitools
 
+__signature__ = 0x1b6d41dceee52002e1073d1948e56fc1
+
 CONTROLLERNAME = 'C-884.DB'  # 'C-884' will also work
 STAGES = ['M-111.1DG', 'M-122.2DD', 'NOSTAGE', 'NOSTAGE']
 REFMODES = ['FNL', 'FRF']
@@ -88,8 +87,14 @@ def main():
         rangemax = pidevice.qTMX()
         curpos = pidevice.qPOS()
 
+        for axis in pidevice.axes:
+            if curpos[axis] > rangemax[axis]:
+                curpos[axis] = rangemax[axis]
+            elif curpos[axis] < rangemin[axis]:
+                curpos[axis] = rangemin[axis]
+
         # The GCS commands qTMN() and qTMX() used above are query commands.
-        # They don't need an argument and will then return all availabe
+        # They don't need an argument and will then return all available
         # information, e.g. the limits for _all_ axes. With setter commands
         # however you have to specify the axes/channels. GCSDevice provides
         # a property "axes" which returns the names of all connected axes.
@@ -123,6 +128,6 @@ if __name__ == '__main__':
     # two hashtags. Then debug messages are shown. This can be helpful if
     # there are any issues.
 
-    # import logging
-    # logging.basicConfig(level=logging.DEBUG)
+    # from pipython import PIlogger, DEBUG, INFO, WARNING, ERROR, CRITICAL
+    # PIlogger.setLevel(DEBUG)
     main()
